#
# spec file for package xf86-video-mga
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-mga
Version:        2.1.0
Release:        1.2
Summary:        Matrox video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Patch0:         u_Change-shadow-fb-implementation-from-DDX-based-to-miext-damage-based.patch
Patch1:         u_Fix-compiler-warnings.patch
Patch4:         u_shadow-Calulate-the-shadow-buffer-size-correctly.patch
Patch5:         n_xorg-server-1.20.patch
BuildRequires:  Mesa-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libdrm) >= 2.0
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.1.0
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v0000102Bd*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%x11_abi_videodrv_req

%description
mga is an Xorg driver for Matrox video cards.

The driver is fully accelerated, and provides support for the following
framebuffer depths: 8, 15, 16, 24, and an 8+24 overlay mode. All visual
types are supported for depth 8, and both TrueColor and DirectColor
visuals are supported for the other depths except 8+24 mode which
supports PseudoColor, GrayScale and TrueColor. Multi-card configurations
are supported. XVideo is supported on G200 and newer systems, with
either TexturedVideo or video overlay. The second head of dual-head
cards is supported for the G450 and G550. Support for the second head on
G400 cards requires a binary-only "mga_hal" module that is available
from Matrox, and may be on the CD supplied with the card. That module
also provides various other enhancements, and may be necessary to use
the DVI (digital) output on the G550 (and other cards).

%prep
%autosetup -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/mga_drv.so
%{_datadir}/man/man4/mga.4%{?ext_man}

%changelog
* Sun Oct 13 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.1.0
  * This release raises the minimum supported version of the Xorg
    server to 1.18 (released in 2015).  This includes the removal
    of the XAA code, which cannot be compiled for any Xserver
    newer than the 1.12 series, as XAA support was removed in the
    Xorg 1.13 release.
- adjusted u_Change-shadow-fb-implementation-from-DDX-based-to-miext-damage-based.patch
  - refreshed patches
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.0.1
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * configure.ac: fix cross-compilation
  * Fix uninitialized read in MGAEnableSecondOutPut
* Fri Aug  2 2019 Stefan Dirsch <sndirsch@suse.com>
- adding to changelog, that
  * U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch fixes
    build against updated xorg-server 1.19 (bsc#1098226)
  * current sources contain latest driver updates for sle12
    (fate #315643-315645, 319159-319161, 319618)
  * we disabled DRI(1) in the driver (no longer supported by Mesa)
* Mon Dec 10 2018 sndirsch@suse.com
- Update to version 2.0.0
  * This is a maintenance release of Matrox DDX.
    Just for disclosure, the code is currently broken for Millennium, Millennium II, and G550.
    For those models, you may have to disable acceleration to workaround the issue. (the workaround is untested)
    The code is untested on Mystique and G100 due to lack of access to the hardware at this time.
    The code works generally okay on G200, G400, and G450.
    That being said, EXA occasionally leaves artifacts and standby resume is currently broken.
    Standby resume used to work, but someone broke the code in the last few years.
    (Kevin Brace, Brace Computer Laboratory, https://bracecomputerlab.com)
- adjusted u_Fix-compiler-warnings.patch,
  u_shadow-Calulate-the-shadow-buffer-size-correctly.patch,
  u_Change-shadow-fb-implementation-from-DDX-based-to-miext-damage-based.patch
- supersedes u_EXA-Fix-UploadToScreen.patch
* Wed May 23 2018 sndirsch@suse.com
- n_xorg-server-1.20.patch
  * fix build against xorg-server 1.20
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041661)
* Thu Jan 19 2017 sndirsch@suse.com
- Update to version 1.6.5
  * Enable write-combining on the framebuffer BAR
  * Adapt Block/WakeupHandler signature for ABI 23
  * Remove DownloadFromScreen
  * Composite fixup
  * Add support for a new G200eW3 chipset
  * Add support for the new G200e chipset -- V2
  * MGA DDX: make it possible to find EXA support
  * Use correct type in function call.
- supersedes U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
- supersedes u_Fix-crash-when-EXA-accel-mode-is-enabled.patch
* Wed Nov 30 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Tue Jul  5 2016 eich@suse.com
- u_shadow-Calulate-the-shadow-buffer-size-correctly.patch
  * Calculate the shadow buffer size correctly to avoid the
    screen being cut off (boo#987670).
* Mon Feb 23 2015 sndirsch@suse.com
- Update to version 1.6.4
  * man: Don't mention the HAL
  * dri: Stop (uselessly) initializing the ValidateTree hooks
  * undef DISABLE_VGA_IO
  * xf86-video-mga: set the pan_ctl register
  * xf86-video-mga: fix a lockup in the mga driver
  * fix a type in previous lockup in the mga driver fix
- supersedes U_dri-Stop-uselessly-initializing-the-ValidateTree-hoo.patch
* Fri Feb  6 2015 sndirsch@suse.com
- U_dri-Stop-uselessly-initializing-the-ValidateTree-hoo.patch
  * fixes build against xorg-server 1.17
* Sun May 11 2014 eich@suse.com
- u_Change-shadow-fb-implementation-from-DDX-based-to-miext-damage-based.patch
  Fix the shadowfb implementation: old implementation produced
  artefacts: Fixed by changing to the mi base shadow method (bnc#876098).
- u_EXA-Fix-UploadToScreen.patch
  Fix EXA UploadToScreen: Images were garbled as writing to aperture didn't wait
  for FIFO to drain. (bnc#876941).
- u_Fix-compiler-warnings.patch
- u_Fix-crash-when-EXA-accel-mode-is-enabled.patch
  Fix segfault in EXA: fb base address was not added to source in
  DownloadFromScreen (bnc#876940).
* Sat Dec  7 2013 zaitor@opensuse.org
- Update to version 1.6.3:
  + mga:
  - Fix XAA runtime.
  - Use exaGetPixmapFirstPixel() instead of devPrivate.ptr.
  + Remove mga_esc.c vestigal stub.
  + Disable HW cursor by default on G200 server chips.
  + Restructure code to make it more readable.
  + Fix dual head crash without XAA (lp#1180986).
  + Unbreak dual head (xinerama) (lp#18472, lp#292214,
    gentoo#265100).
  + Disable Linear Expansion on BE.
  + Restrict kernel driver matching to g200 server chips
    (deb#697532, bnc#823658).
- Drop U_Restrict-kernel-driver-matching-to-g200-server-chips.patch
  and xf86-video-mga-g200se-swcursor.diff, fixed upstream.
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Fri Jun  7 2013 sndirsch@suse.com
- U_Restrict-kernel-driver-matching-to-g200-server-chips.patch
  * Restrict kernel driver matching to g200 server chips. Otherwise
    we might catch devices handled by matroxfb, not the mgag200 kms
    driver. (bnc#823658)
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sat Oct 13 2012 zaitor@opensuse.org
- Update to version 1.6.2:
  + Bring dri1 back to life.
  + Add stub storm functions if not using XAA.
  + Remove mibstore.h.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix mga build after XAA removal.
- Changes of 1.6.0:
  + mga: port to new compat API.
  + Add const qualifier to char *from in MGAdoDDC
  + Move PCI vendor/device id defines into mga.h instead of using
    xf86PciInfo.h
  + mga: don't bind to device if there is a kernel driver, this
    should only pick up KMS drivers and not old drm drivers.
* Fri Jun  1 2012 sndirsch@suse.com
- remove hw supplements (bnc#764395)
* Wed May 23 2012 crrodriguez@opensuse.org
- Use "Supplements" to make the package manager pick
  the driver when the user has the proper hardware.
* Fri Apr 20 2012 vuntz@opensuse.org
- Update to version 1.5.0:
  + Compatibility with Xorg ABI 1.12.
  + Compatibility with some new chipset models and models
    with > 8Mb VRAM.
  + Delete support for MGA's proprietary HAL.
  + When we can't load the xaa or exa modules, use shadowfb
    instead.
  + Various cleanups.
- Rebase xf86-video-mga-g200se-swcursor.diff.
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-mga from xorg-x11-driver-video.
  Initial version: 1.4.13.
